@@ -4,9 +4,9 @@
 
 ;; Author: J.D. Smith <jdtsmith@gmail.com>
 ;; URL: https://github.com/jdtsmith/kind-icon
-;; Package-Requires: ((emacs "27.1") svg-lib)
-;; Version: 0.2.0
-;; Keywords: completion
+;; Package-Requires: ((emacs "27.1") (svg-lib "0.2.8"))
+;; Version: 0.2.1
+;; Keywords: completion convenience
 
 ;; kind-icon is free software: you can redistribute it
 ;; and/or modify it under the terms of the GNU General Public License
@@ -94,7 +94,9 @@ Use as a custom-set function."
     (command "cm" :icon "code-greater-than" :face default)
     (constant "co" :icon "lock-remove-outline" :face font-lock-constant-face)
     (constructor "cn" :icon "table-column-plus-after" :face font-lock-function-name-face)
+    ;; FIXME: remove this once eglot patch is in Emacs
     (enummember "em" :icon "order-bool-ascending-variant" :face font-lock-builtin-face)
+    (enum-member "em" :icon "order-bool-ascending-variant" :face font-lock-builtin-face)
     (enum "e" :icon "format-list-bulleted-square" :face font-lock-builtin-face)
     (event "ev" :icon "lightning-bolt-outline" :face font-lock-warning-face)
     (field "fd" :icon "application-braces-outline" :face font-lock-variable-name-face)
@@ -116,7 +118,9 @@ Use as a custom-set function."
     (string "s" :icon "sticker-text-outline" :face font-lock-string-face)
     (struct "%" :icon "code-braces" :face font-lock-variable-name-face)
     (text "tx" :icon "script-text-outline" :face font-lock-doc-face)
+    ;; FIXME: remove this once eglot patch is in Emacs
     (typeparameter "tp" :icon "format-list-bulleted-type" :face font-lock-type-face)
+    (type-parameter "tp" :icon "format-list-bulleted-type" :face font-lock-type-face)
     (unit "u" :icon "ruler-square" :face font-lock-constant-face)
     (value "v" :icon "plus-circle-outline" :face font-lock-builtin-face)
     (variable "va" :icon "variable" :face font-lock-variable-name-face)
@@ -156,7 +160,7 @@ missing or unspecified, from the frame's background color."
 				       :action kind-icon--preview))
 			(:face (face :tag "Face")))))))
 
-(defcustom kind-icon-blend-background t
+(defcustom kind-icon-blend-background nil
   "Whether to set a custom background blended from foreground."
   :group 'kind-icon
   :type 'boolean
@@ -187,11 +191,11 @@ or (if nil) to the default frame foreground color.  The
 background color is also taken from this face, if provided,
 otherwise defaulting to the frame background color."
   :group 'kind-icon
-  :type 'face
+  :type '(choice face (const :value nil :tag "Default"))
   :set #'kind-icon--set-default-clear-cache)
 
 (defcustom kind-icon-default-style
-  '(:padding 0 :stroke 0 :margin 0 :radius 0 :height 1.0 :scale 1.0)
+  '(:padding 0 :stroke 0 :margin 0 :radius 0 :height 1.0 :scale 1.0 :background nil)
   "Default style parameters for building SVG icons.
 See `svg-lib-style-compute-default'."
   :group 'kind-icon
@@ -209,7 +213,7 @@ value pairs to provide to `svg-lib-icon'."
 	  (apply #'svg-lib-icon icon plist
 		 `(,@kind-icon-default-style
 		   ,@(if col `(:foreground ,col))
-		   ,@(if bg-col `(:background ,bg-col))))
+		   :background ,bg-col)) ; nil = transparent
 	((error)
 	 (warn "Error retrieving icon %s, falling back on short-text\n%s"
 	       icon (cdr err))
@@ -306,14 +310,13 @@ background-color."
 		   (default-bg (if kind-icon-default-face
 				   (face-attribute kind-icon-default-face :background nil t)
 				 (frame-parameter nil 'background-color)))
-		   (bg-col (if (and kind-icon-blend-background (not terminal))
+		   (bg-col (if kind-icon-blend-background
 			       (kind-icon--rgb-blend
 				(color-name-to-rgb col)
 				(color-name-to-rgb default-bg)
 				kind-icon-blend-frac)
 			     (if (and kind-face-bg (not (eq kind-face-bg 'unspecified)))
-				 kind-face-bg
-			       default-bg)))
+				 kind-face-bg)))
 		   (half (/ dfw 2))   ; integer division, may truncate
 		   (face-spec `(:weight bold :foreground ,col :background ,bg-col))
 		   (pad-right (propertize " " 'display `(space :width (,half))
